@@ -183,3 +183,10 @@ void MainWindow::on_actionVauro_triggered()
     browser->openPage(Browser::Vauro);
     browser->show();
 }
+
+void MainWindow::on_pushButton_clicked()
+{
+    Browser *browser = new Browser(this);
+    browser->openPage(Browser::Rete8);
+    browser->show();
+}
